@@ -1,3 +1,10 @@
+/*
+ * Copyright (c) 2019 The Software Heritage developers
+ * See the AUTHORS file at the top-level directory of this distribution
+ * License: GNU General Public License version 3, or any later version
+ * See top-level LICENSE file for more information
+ */
+
 package org.softwareheritage.graph.experiments.forks;
 
 import com.google.common.primitives.Longs;
@@ -7,8 +14,8 @@ import it.unimi.dsi.bits.LongArrayBitVector;
 import it.unimi.dsi.fastutil.Arrays;
 import it.unimi.dsi.io.ByteDiskQueue;
 import it.unimi.dsi.logging.ProgressLogger;
-import org.softwareheritage.graph.Graph;
-import org.softwareheritage.graph.Node;
+import org.softwareheritage.graph.SwhBidirectionalGraph;
+import org.softwareheritage.graph.SwhType;
 
 import java.io.File;
 import java.io.FileNotFoundException;
@@ -17,7 +24,7 @@ import java.util.*;
 
 public class ForkCC {
     public Boolean includeRootDir;
-    private Graph graph;
+    private SwhBidirectionalGraph graph;
     private Long emptySnapshot;
     private LongArrayBitVector visited;
     private LongArrayBitVector whitelist;
@@ -72,7 +79,7 @@ public class ForkCC {
 
     private void load_graph(String graphBasename) throws IOException {
         System.err.println("Loading graph " + graphBasename + " ...");
-        this.graph = Graph.loadMapped(graphBasename).symmetrize();
+        this.graph = SwhBidirectionalGraph.loadMapped(graphBasename).symmetrize();
         System.err.println("Graph loaded.");
         this.emptySnapshot = null;
         this.whitelist = null;
@@ -81,7 +88,7 @@ public class ForkCC {
     }
 
     private boolean nodeIsEmptySnapshot(Long node) {
-        if (this.emptySnapshot == null && this.graph.getNodeType(node) == Node.Type.SNP
+        if (this.emptySnapshot == null && this.graph.getNodeType(node) == SwhType.SNP
                 && this.graph.outdegree(node) == 0) {
             System.err.println("Found empty snapshot: " + node);
             this.emptySnapshot = node;
@@ -90,11 +97,11 @@ public class ForkCC {
     }
 
     private Boolean shouldVisit(Long node) {
-        Node.Type nt = this.graph.getNodeType(node);
-        if (nt == Node.Type.CNT) {
+        SwhType nt = this.graph.getNodeType(node);
+        if (nt == SwhType.CNT) {
             return false;
         }
-        if (nt == Node.Type.DIR && !includeRootDir)
+        if (nt == SwhType.DIR && !includeRootDir)
             return false;
         if (this.nodeIsEmptySnapshot(node))
             return false;
@@ -122,7 +129,7 @@ public class ForkCC {
         ArrayList<ArrayList<Long>> components = new ArrayList<>();
 
         for (long i = 0; i < n; i++) {
-            if (!shouldVisit(i) || this.graph.getNodeType(i) == Node.Type.DIR)
+            if (!shouldVisit(i) || this.graph.getNodeType(i) == SwhType.DIR)
                 continue;
 
             ArrayList<Long> component = new ArrayList<>();
@@ -133,8 +140,8 @@ public class ForkCC {
             while (!queue.isEmpty()) {
                 queue.dequeue(byteBuf);
                 final long currentNode = Longs.fromByteArray(byteBuf);
-                Node.Type cur_nt = this.graph.getNodeType(currentNode);
-                if (cur_nt == Node.Type.ORI && (this.whitelist == null || this.whitelist.getBoolean(currentNode))) {
+                SwhType cur_nt = this.graph.getNodeType(currentNode);
+                if (cur_nt == SwhType.ORI && (this.whitelist == null || this.whitelist.getBoolean(currentNode))) {
                     // TODO: add a check that the origin has >=1 non-empty snapshot
                     component.add(currentNode);
                 }
@@ -144,7 +151,7 @@ public class ForkCC {
                 while ((succ = iterator.nextLong()) != -1) {
                     if (!shouldVisit(succ))
                         continue;
-                    if (this.graph.getNodeType(succ) == Node.Type.DIR && cur_nt != Node.Type.REV)
+                    if (this.graph.getNodeType(succ) == SwhType.DIR && cur_nt != SwhType.REV)
                         continue;
                     visited.set(succ);
                     queue.enqueue(Longs.toByteArray(succ));
