@@ -1,3 +1,10 @@
+/*
+ * Copyright (c) 2020 The Software Heritage developers
+ * See the AUTHORS file at the top-level directory of this distribution
+ * License: GNU General Public License version 3, or any later version
+ * See top-level LICENSE file for more information
+ */
+
 package org.softwareheritage.graph.experiments.topology;
 
 import com.martiansoftware.jsap.*;
@@ -8,15 +15,15 @@ import it.unimi.dsi.fastutil.BigArrays;
 import it.unimi.dsi.fastutil.longs.LongBigArrays;
 import it.unimi.dsi.logging.ProgressLogger;
 import it.unimi.dsi.util.XoRoShiRo128PlusRandom;
-import org.softwareheritage.graph.Graph;
-import org.softwareheritage.graph.Node;
+import org.softwareheritage.graph.SwhBidirectionalGraph;
+import org.softwareheritage.graph.SwhType;
 
 import java.io.*;
 import java.util.*;
 import java.util.concurrent.*;
 
 public class ClusteringCoefficient {
-    private final Graph graph;
+    private final SwhBidirectionalGraph graph;
     private final String outdirPath;
     private final ConcurrentHashMap<Long, Long> result_full;
     private final ConcurrentHashMap<Long, Long> result_dircnt;
@@ -27,7 +34,7 @@ public class ClusteringCoefficient {
     public ClusteringCoefficient(String graphBasename, String outdirPath) throws IOException {
         this.outdirPath = outdirPath;
         System.err.println("Loading graph " + graphBasename + " ...");
-        Graph directedGraph = Graph.loadMapped(graphBasename);
+        SwhBidirectionalGraph directedGraph = SwhBidirectionalGraph.loadMapped(graphBasename);
         this.graph = directedGraph.symmetrize();
         System.err.println("Graph loaded.");
 
@@ -68,7 +75,7 @@ public class ClusteringCoefficient {
 
         service.submit(() -> {
             try {
-                Graph thread_graph = graph.copy();
+                SwhBidirectionalGraph thread_graph = graph.copy();
 
                 long[][] randomPerm = Util.identity(thread_graph.numNodes());
                 LongBigArrays.shuffle(randomPerm, new XoRoShiRo128PlusRandom());
@@ -103,7 +110,7 @@ public class ClusteringCoefficient {
         for (int i = 0; i < numThreads; ++i) {
             service.submit(() -> {
                 try {
-                    Graph thread_graph = graph.copy();
+                    SwhBidirectionalGraph thread_graph = graph.copy();
                     while (true) {
                         Long node = null;
                         try {
@@ -127,12 +134,12 @@ public class ClusteringCoefficient {
         service.awaitTermination(365, TimeUnit.DAYS);
     }
 
-    private void computeAt(Graph graph, long node) {
+    private void computeAt(SwhBidirectionalGraph graph, long node) {
         long d = graph.outdegree(node);
         if (d < 2) {
             return;
         }
-        Node.Type nodeType = graph.getNodeType(node);
+        SwhType nodeType = graph.getNodeType(node);
 
         HashSet<Long> neighborhood = new HashSet<>();
         long succ;
@@ -148,26 +155,25 @@ public class ClusteringCoefficient {
         long triangles_orisnp = 0;
 
         for (Long neighbor : neighborhood) {
-            Node.Type neighborNodeType = graph.getNodeType(neighbor);
+            SwhType neighborNodeType = graph.getNodeType(neighbor);
             final LazyLongIterator it = graph.successors(neighbor);
             while ((succ = it.nextLong()) != -1) {
                 if (neighborhood.contains(succ)) {
-                    Node.Type succNodeType = graph.getNodeType(succ);
+                    SwhType succNodeType = graph.getNodeType(succ);
                     triangles_full++;
-                    if ((nodeType == Node.Type.DIR || nodeType == Node.Type.CNT)
-                            && (neighborNodeType == Node.Type.DIR || neighborNodeType == Node.Type.CNT)
-                            && (succNodeType == Node.Type.DIR || succNodeType == Node.Type.CNT)) {
+                    if ((nodeType == SwhType.DIR || nodeType == SwhType.CNT)
+                            && (neighborNodeType == SwhType.DIR || neighborNodeType == SwhType.CNT)
+                            && (succNodeType == SwhType.DIR || succNodeType == SwhType.CNT)) {
                         triangles_dircnt++;
-                    } else if ((nodeType == Node.Type.REV || nodeType == Node.Type.REL)
-                            && (neighborNodeType == Node.Type.REV || neighborNodeType == Node.Type.REL)
-                            && (succNodeType == Node.Type.REV || succNodeType == Node.Type.REL)) {
+                    } else if ((nodeType == SwhType.REV || nodeType == SwhType.REL)
+                            && (neighborNodeType == SwhType.REV || neighborNodeType == SwhType.REL)
+                            && (succNodeType == SwhType.REV || succNodeType == SwhType.REL)) {
                         triangles_revrel++;
-                        if (nodeType == Node.Type.REV && neighborNodeType == Node.Type.REV
-                                && succNodeType == Node.Type.REV)
+                        if (nodeType == SwhType.REV && neighborNodeType == SwhType.REV && succNodeType == SwhType.REV)
                             triangles_rev++;
-                    } else if ((nodeType == Node.Type.ORI || nodeType == Node.Type.SNP)
-                            && (neighborNodeType == Node.Type.ORI || neighborNodeType == Node.Type.SNP)
-                            && (succNodeType == Node.Type.ORI || succNodeType == Node.Type.SNP)) {
+                    } else if ((nodeType == SwhType.ORI || nodeType == SwhType.SNP)
+                            && (neighborNodeType == SwhType.ORI || neighborNodeType == SwhType.SNP)
+                            && (succNodeType == SwhType.ORI || succNodeType == SwhType.SNP)) {
                         triangles_orisnp++;
                     }
                 }
